MpayPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MpayPluginPlatform
Implementers

Constructors

MpayPluginPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aliPay(String data, String setIosUrlSchema) Future<Map>
支付寶支付
generateQrCode(String code, {int size = 256}) Future<Uint8List?>
生成扫码支付二维码(原生端渲染),返回 PNG 字节。 code 为商户服务端返回的二维码内容字符串 (支付宝 precreate 的 qr_code / 微信统一下单 NATIVE 的 code_url)。
getPlatformVersion() Future<String?>
init({AliPayEnv aliPayEnv = AliPayEnv.ONLINE, MPayEnv mPayEnv = MPayEnv.PRODUCTION}) Future<void>
初始化设置(
mPay(String? data, {PayChannel channel = PayChannel.mPay, String? withScheme}) Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerApi({required String appId, bool doOnIOS = true, bool doOnAndroid = true, String? universalLink}) Future<bool>
toString() String
A string representation of this object.
inherited
wechatPay(PayType which) Future<Map>
微信支付

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MpayPluginPlatform
getter/setter pair